.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to HydroBM's documentation!
==================================================

HydroBM is a shorthand for "Hydrologic Timeseries Benchmarks".
HydroBM is a Python package that provides a simple framework to create benchmark timeseries for hydrologic models.

Extra features:

* Calculate various performance metrics for the benchmark simulations.
* Run a simple degree-day model for snow accumulation and melt simulation.


Contents:
=========
.. toctree::
   :maxdepth: 2

   installation
   usage
   ./example/example
   release-history
